.. -*- coding: utf-8 -*-

===============================
Installable Packages for PyBill
===============================

Logilab provides **Debian packages** for PyBill. These packages can be
downloaded from `Logilab Debian repository`_\ . 

You can read this `information card`_ on Logilab forge for further information.

.. _`Logilab Debian repository`: http://ftp.logilab.org/dists/
.. _`information card`: http://www.logilab.org/card/LogilabDebianRepository

